==> vokoscreen-ng_3.1.0.orig.tar.gz: vokoscreenNG-3.1.0/src/language/vi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="vi">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Chọn một hoặc nhiều thiết bị</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Đổi sang cửa sổ nhỏ</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Đổi sang toàn màn hình</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Chọn một hoặc nhiều thiết bị</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Hỗ trợ</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Không tìm được filemanager</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Xin cài đặt filemanager</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Cảnh báo</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Ghi hình chưa bắt đầu, không đủ dung lượng ổ đĩa trống</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Dung lượng ổ đĩa trống đã đạt giới hạn</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Giới hạn ổ đĩa trống</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Ghi hình đã kết thúc, không đủ dung lượng ổ đĩa trống</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Toàn màn hình</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Cửa sổ</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Không tìm được filemanager</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Xin cài đặt filemanager</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Mã nguồn</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Trang chủ</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Chuyển ngữ</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Ủng hộ tài chính</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Chọn một hoặc nhiều thiết bị</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Khu vực</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Bắt đầu</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Dừng lại</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Tạm dừng</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Tiếp tục</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Thoát</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Phóng to</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Bắt đầu</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Dừng lại</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Tạm dừng</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Tiếp tục</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Thoát</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Hộp thoại</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Đổi sang chiều ngang</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Đổi sang chiều dọc</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Đổi ngược lại</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Xám</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Trắng Đen</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Xóa khung hình</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Cài đặt Camera</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Khu vực</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Khởi động lại</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Phóng to</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Đếm ngược</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Kích cỡ Video</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Dung lượng đĩa trống</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Thông tin</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Thời gian ghi hình</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Khung ảnh</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videocodec</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Định dạng</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Audiocodec</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Chất lượng</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Không ghi hình phần hiển thị của chuột</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Giờ</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Phút</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Bắt đầu đếm giờ</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Dừng ghi hình sau</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Giờ</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Phút</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Giây</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Đường dẫn video</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Giới hạn ổ đĩa trống</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Hiển thị trong systray</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Số giây đợi trước khi ghi hình</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Tìm cập nhật</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hỗ trợ</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Có sẵn</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Không có sẵn</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Bắt đầu</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Dừng lại</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Tạm dừng</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Tiếp tục</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Phát</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Thư mục</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Đổi ngược lại</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Xám</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Gửi báo cáo</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Phát đoạn ghi hình gần nhất</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Mở thư mục</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Ẩn màn hình khi bắt đầu ghi hình</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Bắt đầu ẩn màn hình</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Đổi sang chiều ngang</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Đổi sang chiều dọc</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Trắng Đen</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Xóa khung hình</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Ủng hộ tài chính</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Reset tất cả cài đặt ở lần chay tới</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Quyền sở hữu và giấy phép sử dụng bức tranh</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Quay màn hình</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Trình phát</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Nhật ký</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Quyền sở hữu và giấy phép sử dụng bức tranh</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Phát</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Tạm dừng</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Dừng lại</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Mở File</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Toàn màn hình</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Khung hình trước</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Khung hình sau</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Tắt tiếng</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Dời menu</translation>
    </message>
</context>
</TS>

==> vokoscreen-ng_3.3.0.orig.tar.gz: vokoscreenNG-3.3.0/src/language/vi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="vi">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Chọn một hoặc nhiều thiết bị</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Đổi sang cửa sổ nhỏ</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Đổi sang toàn màn hình</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation>Thiết lập thành công.</translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation>Đóng cửa sổ này và khởi động lại vokoscreenNG.</translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation>Chúc bạn vui vẻ với vokoscreenNG</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Chọn một hoặc nhiều thiết bị</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Hỗ trợ</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Không tìm thấy trình quản lý tệp.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Vui lòng cài đặt trình quản lý tệp.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Cảnh báo</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Ghi hình chưa bắt đầu, không đủ dung lượng ổ đĩa trống</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Dung lượng ổ đĩa trống đã đạt giới hạn</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Giới hạn ổ đĩa trống</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Ghi hình đã kết thúc, không đủ dung lượng ổ đĩa trống</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Toàn màn hình</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Cửa sổ</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Không tìm thấy trình quản lý tệp.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Vui lòng cài đặt trình quản lý tệp.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Mã nguồn</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Trang chủ</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Chuyển ngữ</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Ủng hộ tài chính</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Chọn một hoặc nhiều thiết bị</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Khu vực</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Khu vực</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Bắt đầu</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Dừng lại</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Tạm dừng</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Tiếp tục</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Thoát</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Phóng to</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Bắt đầu</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Dừng lại</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Tạm dừng</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Tiếp tục</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Thoát</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Phóng to</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Hộp thoại</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Đổi sang chiều ngang</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Đổi sang chiều dọc</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Đổi ngược lại</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Xám</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Trắng Đen</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Xóa khung hình</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Cài đặt Camera</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Khu vực</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Khởi động lại</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Phóng to</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Đếm ngược</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Kích cỡ Video</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Dung lượng đĩa trống</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Thông tin</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Thời gian ghi hình</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Khung ảnh</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videocodec</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Định dạng</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Audiocodec</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Chất lượng</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Không ghi hình phần hiển thị của chuột</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Giờ</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Phút</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Bắt đầu đếm giờ</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Dừng ghi hình sau</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Giờ</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Phút</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Giây</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Đường dẫn video</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Giới hạn ổ đĩa trống</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Hiển thị trong systray</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Số giây đợi trước khi ghi hình</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Tìm cập nhật</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hỗ trợ</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Có sẵn</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Không có sẵn</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Bắt đầu</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Dừng lại</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Tạm dừng</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Tiếp tục</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Phát</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Thư mục</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Đổi ngược lại</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Xám</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Gửi báo cáo</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Phát đoạn ghi hình gần nhất</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Mở thư mục</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Ẩn màn hình khi bắt đầu ghi hình</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Bắt đầu ẩn màn hình</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Đổi sang chiều ngang</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Đổi sang chiều dọc</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Trắng Đen</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Xóa khung hình</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Ủng hộ tài chính</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Reset tất cả cài đặt ở lần chay tới</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Quyền sở hữu và giấy phép sử dụng bức tranh</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Quay màn hình</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Trình phát</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Nhật ký</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation>Tự động</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Tạo hình ảnh của các tab</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Thông tin giấy phép</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>BẬT</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>TẮT</translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation>Các phím tắt chung</translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation>Các phím tắt được chỉ định.</translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation>Phím tắt không được chỉ định hoặc được chỉ định nhiều lần.</translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation>Nếu nó hiển thị được chỉ định nhưng không hoạt động, nó đang được sử dụng bởi một chương trình khác.</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Quyền sở hữu và giấy phép sử dụng bức tranh</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Phát</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Tạm dừng</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Dừng lại</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Mở File</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Toàn màn hình</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Khung hình trước</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Khung hình sau</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Tắt tiếng</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Dời menu</translation>
    </message>
</context>
</TS>
